<?php
/**
 * Twenty Twenty-Four functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Twenty Twenty-Four
 * @since Twenty Twenty-Four 1.0
 */

/**
 * Register block styles.
 */

if ( ! function_exists( 'gotemplate_block_styles' ) ) :
	/**
	 * Register custom block styles
	 *
	 * @since Twenty Twenty-Four 1.0
	 * @return void
	 */
	function gotemplate_block_styles() {

		register_block_style(
			'core/details',
			array(
				'name'         => 'arrow-icon-details',
				'label'        => __( 'Arrow icon', 'gotemplate' ),
				/*
				 * Styles for the custom Arrow icon style of the Details block
				 */
				'inline_style' => '
				.is-style-arrow-icon-details {
					padding-top: var(--wp--preset--spacing--10);
					padding-bottom: var(--wp--preset--spacing--10);
				}

				.is-style-arrow-icon-details summary {
					list-style-type: "\2193\00a0\00a0\00a0";
				}

				.is-style-arrow-icon-details[open]>summary {
					list-style-type: "\2192\00a0\00a0\00a0";
				}',
			)
		);
		register_block_style(
			'core/post-terms',
			array(
				'name'         => 'pill',
				'label'        => __( 'Pill', 'gotemplate' ),
				/*
				 * Styles variation for post terms
				 * https://github.com/WordPress/gutenberg/issues/24956
				 */
				'inline_style' => '
				.is-style-pill a,
				.is-style-pill span:not([class], [data-rich-text-placeholder]) {
					display: inline-block;
					background-color: var(--wp--preset--color--base-2);
					padding: 0.375rem 0.875rem;
					border-radius: var(--wp--preset--spacing--20);
				}

				.is-style-pill a:hover {
					background-color: var(--wp--preset--color--contrast-3);
				}',
			)
		);
		register_block_style(
			'core/list',
			array(
				'name'         => 'checkmark-list',
				'label'        => __( 'Checkmark', 'gotemplate' ),
				/*
				 * Styles for the custom checkmark list block style
				 * https://github.com/WordPress/gutenberg/issues/51480
				 */
				'inline_style' => '
				ul.is-style-checkmark-list {
					list-style-type: disc;
				}

				ul.is-style-checkmark-list li {
					padding-inline-start: 1ch;
				}',
			)
		);
		register_block_style(
			'core/navigation-link',
			array(
				'name'         => 'arrow-link',
				'label'        => __( 'With arrow', 'gotemplate' ),
				/*
				 * Styles for the custom arrow nav link block style
				 */
				'inline_style' => '
				.is-style-arrow-link .wp-block-navigation-item__label:after {
					content: "\2197";
					padding-inline-start: 0.25rem;
					vertical-align: middle;
					text-decoration: none;
					display: inline-block;
				}',
			)
		);
		register_block_style(
			'core/heading',
			array(
				'name'         => 'asterisk-inverse',
				'label'        => __( 'With inverse asterisk', 'gotemplate' ),
				'inline_style' => "
				.is-style-asterisk-inverse:before {
					content: '';
					width: 1.5rem;
					height: 3rem;
					background: var(--wp--preset--color--base, currentColor);
					clip-path: path('M11.93.684v8.039l5.633-5.633 1.216 1.23-5.66 5.66h8.04v1.737H13.2l5.701 5.701-1.23 1.23-5.742-5.742V21h-1.737v-8.094l-5.77 5.77-1.23-1.217 5.743-5.742H.842V9.98h8.162l-5.701-5.7 1.23-1.231 5.66 5.66V.684h1.737Z');
					display: block;
				}

				/* Hide the asterisk if the heading has no content, to avoid using empty headings to display the asterisk only, which is an A11Y issue */
				.is-style-asterisk:empty:before {
					content: none;
				}

				.is-style-asterisk:-moz-only-whitespace:before {
					content: none;
				}

				.is-style-asterisk.has-text-align-center:before {
					margin: 0 auto;
				}

				.is-style-asterisk.has-text-align-right:before {
					margin-left: auto;
				}

				.rtl .is-style-asterisk.has-text-align-left:before {
					margin-right: auto;
				}",
			)
		);
		register_block_style(
			'core/heading',
			array(
				'name'         => 'asterisk',
				'label'        => __( 'With asterisk', 'gotemplate' ),
				'inline_style' => "
				.is-style-asterisk:before {
					content: '';
					width: 1.5rem;
					height: 3rem;
					background: var(--wp--preset--color--accent, currentColor);
					clip-path: path('M11.93.684v8.039l5.633-5.633 1.216 1.23-5.66 5.66h8.04v1.737H13.2l5.701 5.701-1.23 1.23-5.742-5.742V21h-1.737v-8.094l-5.77 5.77-1.23-1.217 5.743-5.742H.842V9.98h8.162l-5.701-5.7 1.23-1.231 5.66 5.66V.684h1.737Z');
					display: block;
				}

				/* Hide the asterisk if the heading has no content, to avoid using empty headings to display the asterisk only, which is an A11Y issue */
				.is-style-asterisk:empty:before {
					content: none;
				}

				.is-style-asterisk:-moz-only-whitespace:before {
					content: none;
				}

				.is-style-asterisk.has-text-align-center:before {
					margin: 0 auto;
				}

				.is-style-asterisk.has-text-align-right:before {
					margin-left: auto;
				}

				.rtl .is-style-asterisk.has-text-align-left:before {
					margin-right: auto;
				}",
			)
		);
	}
endif;

add_action( 'init', 'gotemplate_block_styles' );

/**
 * Enqueue block stylesheets.
 */

if ( ! function_exists( 'gotemplate_block_stylesheets' ) ) :
	/**
	 * Enqueue custom block stylesheets
	 *
	 * @since Twenty Twenty-Four 1.0
	 * @return void
	 */
	function gotemplate_block_stylesheets() {
		/**
		 * The wp_enqueue_block_style() function allows us to enqueue a stylesheet
		 * for a specific block. These will only get loaded when the block is rendered
		 * (both in the editor and on the front end), improving performance
		 * and reducing the amount of data requested by visitors.
		 *
		 * See https://make.wordpress.org/core/2021/12/15/using-multiple-stylesheets-per-block/ for more info.
		 */
		wp_enqueue_block_style(
			'core/button',
			array(
				'handle' => 'gotemplate-button-style-outline',
				'src'    => get_parent_theme_file_uri( 'assets/css/button-outline.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/button-outline.css' ),
			)
		);
		wp_enqueue_block_style(
			'core/button',
			array(
				'handle' => 'gotemplate-custom-styles',
				'src'    => get_parent_theme_file_uri( 'assets/css/custom.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/custom.css' ),
			)
		);
	}
endif;

add_action( 'init', 'gotemplate_block_stylesheets' );

function gotemplate_enqueue_styles() {
    wp_enqueue_style(
        'gotemplate-custom-styles',
        get_template_directory_uri() . '/assets/css/custom.css',
        array(),
        wp_get_theme()->get('Version')
    );
}
add_action('wp_enqueue_scripts', 'gotemplate_enqueue_styles');

/**
 * Register pattern categories.
 */

if ( ! function_exists( 'gotemplate_pattern_categories' ) ) :
	/**
	 * Register pattern categories
	 *
	 * @since Twenty Twenty-Four 1.0
	 * @return void
	 */
	function gotemplate_pattern_categories() {

		register_block_pattern_category(
			'page',
			array(
				'label'       => _x( 'Pages', 'Block pattern category' ),
				'description' => __( 'A collection of full page layouts.' ),
			)
		);
	}
endif;

add_action( 'init', 'gotemplate_pattern_categories' );

/**
 * Add essential footer structure functions to theme 
 * File: functions.php or includes/footer-functions.php
 */

/**
 * Generate the footer wrapper and pattern SVG
 * 
 * @return void Echoes the HTML for the footer wrapper and pattern
 */

add_action('wp_footer', function () {
    ?>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const footer = document.querySelector('footer');
            if (footer) {
                const customHTML = document.createElement('div');
                customHTML.innerHTML = `
				<div class="c-footer__pattern">
				<!-- Simple SVG pattern for the footer background -->
				<svg viewBox="0 0 531 516" fill="none" xmlns="http://www.w3.org/2000/svg">
				<g clip-path="url(#clip0_513_51)">
				<path d="M85.2139 344.679C85.2139 355.987 87.4411 367.184 91.7684 377.631C96.0956 388.078 102.438 397.57 110.434 405.566C118.43 413.562 127.922 419.904 138.369 424.232C148.816 428.559 160.013 430.786 171.321 430.786V344.679H85.2139Z" fill="#532464"/>
				<path d="M-0.893066 430.786C21.9439 430.786 43.8456 421.714 59.9937 405.566C76.1419 389.418 85.2139 367.516 85.2139 344.679H-0.893066V430.786Z" fill="#532464"/>
				<path d="M171.321 430.786C160.013 430.786 148.816 433.013 138.369 437.341C127.922 441.668 118.43 448.011 110.434 456.006C102.438 464.002 96.0956 473.494 91.7684 483.941C87.4411 494.388 85.2139 505.585 85.2139 516.893H171.321V430.786Z" fill="#532464"/>
				<path d="M85.2139 516.893C85.2139 505.585 82.9867 494.388 78.6594 483.941C74.3321 473.494 67.9895 464.002 59.9938 456.006C51.998 448.011 42.5056 441.668 32.0586 437.341C21.6117 433.013 10.4147 430.786 -0.893066 430.786V516.893H85.2139Z" fill="#532464"/>
				<path d="M-0.893066 172.465L-0.893066 344.679H22.673L22.673 172.465H-0.893066Z" fill="#C4004B"/>
				<path d="M48.0527 172.465L48.0527 344.679H71.6188L71.6188 172.465H48.0527Z" fill="#C4004B"/>
				<path d="M96.9976 172.465L96.9976 344.679H120.564L120.564 172.465H96.9976Z" fill="#C4004B"/>
				<path d="M147.755 172.465V344.679H171.321V172.465H147.755Z" fill="#C4004B"/>
				<path d="M171.321 148.899C168.226 148.899 165.162 149.508 162.303 150.693C159.444 151.877 156.846 153.613 154.657 155.801C152.469 157.99 150.733 160.588 149.549 163.447C148.365 166.306 147.755 169.37 147.755 172.465H171.321V148.899Z" fill="#532464"/>
				<path d="M171.321 98.1411C161.561 98.1411 151.896 100.064 142.879 103.799C133.861 107.534 125.668 113.008 118.766 119.91C111.865 126.812 106.39 135.005 102.655 144.022C98.9198 153.04 96.9973 162.705 96.9973 172.465H120.586C120.586 165.802 121.899 159.205 124.448 153.05C126.998 146.894 130.735 141.301 135.446 136.59C140.157 131.879 145.75 128.142 151.906 125.592C158.061 123.042 164.659 121.73 171.321 121.73V98.1411Z" fill="#532464"/>
				<path d="M171.321 49.1958C155.133 49.1958 139.104 52.3842 124.148 58.5791C109.193 64.7739 95.6037 73.8539 84.1571 85.3004C72.7105 96.747 63.6306 110.336 57.4358 125.292C51.2409 140.247 48.0525 156.277 48.0525 172.465H71.6572C71.6572 159.377 74.2351 146.417 79.2437 134.325C84.2523 122.233 91.5935 111.246 100.848 101.991C110.103 92.7368 121.09 85.3956 133.182 80.387C145.273 75.3784 158.233 72.8005 171.321 72.8005V49.1958Z" fill="#532464"/>
				<path d="M171.321 0.251953C148.705 0.251953 126.311 4.7064 105.417 13.361C84.5235 22.0155 65.5387 34.7007 49.5472 50.6922C33.5557 66.6838 20.8705 85.6685 12.2159 106.562C3.56137 127.456 -0.89307 149.85 -0.893066 172.466H22.7024C22.7024 152.949 26.5465 133.623 34.0153 115.592C41.484 97.5608 52.4312 81.1772 66.2317 67.3767C80.0322 53.5762 96.4158 42.6291 114.447 35.1603C132.478 27.6915 151.804 23.8474 171.321 23.8474V0.251953Z" fill="#532464"/>
				</g>
				<g clip-path="url(#clip1_513_51)">
				<path d="M458.077 567.069C470.968 536.738 471.281 502.529 458.95 471.968L343.716 518.465L458.077 567.069Z" fill="#C4004B"/>
				<path d="M229.354 469.862C216.464 500.192 216.15 534.401 228.482 564.963L343.716 518.465L229.354 469.862Z" fill="#C4004B"/>
				<path d="M392.319 404.105C361.989 391.215 327.78 390.901 297.218 403.233L343.715 518.467L392.319 404.105Z" fill="#C4004B"/>
				<path d="M516.867 448.598C498.337 402.675 462.323 365.995 416.748 346.625L391.917 405.051C421.997 417.835 445.766 442.044 457.996 472.353L516.867 448.598Z" fill="#C4004B"/>
				<path d="M273.848 345.316C227.926 363.847 191.245 399.86 171.876 445.435L230.302 470.266C243.085 440.187 267.295 416.418 297.603 404.188L273.848 345.316Z" fill="#C4004B"/>
				</g>
				<defs>
				<clipPath id="clip0_513_51">
				<rect width="344" height="516" fill="white"/>
				</clipPath>
				<clipPath id="clip1_513_51">
				<rect width="374" height="185" fill="white" transform="translate(157 331)"/>
				</clipPath>
				</defs>
				</svg>
			</div>
				`;
                footer.appendChild(customHTML);
            }
        });
    </script>
    <?php
});
